@@ -1,4 +1,4 @@
-#' Distances to Class Centroids
+#' Distances to class centroids
 #'
 #' `step_classdist()` creates a *specification* of a recipe step that will
 #' convert numeric data into Mahalanobis distance measurements to the data
@@ -42,9 +42,15 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#' `terms` (the selectors or variables selected), `value` (the centroid
-#' of the class), and `class` is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `value`, `class` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{value}{numeric, location of centroid}
+#'   \item{class}{character, name of the class}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-supervised
 #'
@@ -94,9 +100,8 @@ step_classdist <- function(recipe,
                            keep_original_cols = TRUE,
                            skip = FALSE,
                            id = rand_id("classdist")) {
-  if (!is.character(class) || length(class) != 1) {
-    rlang::abort("`class` should be a single character value.")
-  }
+  check_string(class)
+
   add_step(
     recipe,
     step_classdist_new(
@@ -142,7 +147,9 @@ step_classdist_new <-
 
 get_center <- function(x, wts = NULL, mfun = mean) {
   if (!is.null(wts) & !identical(mfun, mean)) {
-    rlang::abort("The centering function requested cannot be used with case weights.")
+    cli::cli_abort(
+      "The centering function requested cannot be used with case weights."
+    )
   }
   x <- tibble::as_tibble(x)
   if (is.null(wts)) {
@@ -155,10 +162,14 @@ get_center <- function(x, wts = NULL, mfun = mean) {
 
 get_both <- function(x, wts = NULL, mfun = mean, cfun = cov) {
   if (!is.null(wts) & !identical(mfun, mean)) {
-    rlang::abort("The centering function requested cannot be used with case weights.")
+    cli::cli_abort(
+      "The centering function requested cannot be used with case weights."
+    )
   }
   if (!is.null(wts) & !identical(cfun, cov)) {
-    rlang::abort("The variance function requested cannot be used with case weights.")
+    cli::cli_abort(
+      "The variance function requested cannot be used with case weights."
+    )
   }
 
   if (is.null(wts)) {
