@@ -1,4 +1,4 @@
-#' Kernel PCA Signal Extraction
+#' Kernel PCA signal extraction
 #'
 #' `step_kpca()` creates a *specification* of a recipe step that will convert
 #' numeric data into one or more principal components using a kernel basis
@@ -26,6 +26,18 @@
 #'
 #' @template kpca-info
 #'
+#' @details
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{id}{character, id of this step}
+#' }
+#'
 #' @template case-weights-not-supported
 #'
 #' @examplesIf rlang::is_installed(c("modeldata", "ggplot2", "kernlab"))
@@ -126,7 +138,10 @@ prep.step_kpca <- function(x, training, info = NULL, ...) {
     cl <- call_modify(cl, !!!x$options)
     kprc <- try(rlang::eval_tidy(cl), silent = TRUE)
     if (inherits(kprc, "try-error")) {
-      rlang::abort(paste0("`step_kpca` failed with error:\n", as.character(kprc)))
+      cli::cli_abort(c(
+        x = "Failed with error:",
+        i = as.character(kprc)
+      ))
     }
   } else {
     kprc <- NULL
